aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/codec/SkFrameHolder.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/codec/SkFrameHolder.h')
-rw-r--r--src/codec/SkFrameHolder.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/codec/SkFrameHolder.h b/src/codec/SkFrameHolder.h
index 29539ff908..ab308b39db 100644
--- a/src/codec/SkFrameHolder.h
+++ b/src/codec/SkFrameHolder.h
@@ -40,14 +40,14 @@ public:
int frameId() const { return fId; }
/**
- * Whether this frame reports alpha.
+ * How this frame reports its alpha.
*
* This only considers the rectangle of this frame, and
* considers it to have alpha even if it is opaque once
* blended with the frame behind it.
*/
- bool reportsAlpha() const {
- return this->onReportsAlpha();
+ SkEncodedInfo::Alpha reportedAlpha() const {
+ return this->onReportedAlpha();
}
/**
@@ -130,7 +130,7 @@ public:
}
protected:
- virtual bool onReportsAlpha() const = 0;
+ virtual SkEncodedInfo::Alpha onReportedAlpha() const = 0;
private:
static constexpr int kUninitialized = -2;
@@ -166,7 +166,7 @@ public:
/**
* Compute the opacity and required frame, based on
* whether the frame reportsAlpha and how it blends
* with prior frames.
*/
void setAlphaAndRequiredFrame(SkFrame*);
@@ -166,7 +166,7 @@ public:
/**
* Compute the opacity and required frame, based on
- * whether the frame reportsAlpha and how it blends
+ * the frame's reportedAlpha and how it blends
* with prior frames.
*/